% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dobserv_funcs.R
\name{dobserv_dep_obs}
\alias{dobserv_dep_obs}
\title{runs double-observer analysis for dependent observers}
\usage{
dobserv_dep_obs(dobs_data, mods = c(~obs, ~sp, ~sp + obs, ~sp * obs))
}
\arguments{
\item{dobs_data}{data frame with the following fields:\cr
\itemize{
 \item \code{obs} observer number for primary observer
 \item \code{species} name of species
 \item \code{X1.} number of individuals of species detected by primary observer
 \item \code{X01} number of individuals of species detected by secondary
   observer that were missed by primary observer
 }}

\item{mods}{list of model definitions. Model definitions are in GLM form.\cr
 \itemize{
 \item \code{~1} means detection is constant for all observers and species.\cr
 \item \code{~sp} means detection varies by species (constant across observers)\cr
 \item \code{~obs} means detection varies by observer (constant across species)\cr
 \item \code{~sp*obs} means detection varies by species and observer\cr
 \item \code{~xxxx} means detection varies by input covariate, xxxx\cr
}}
}
\value{
aic table of model results
}
\description{
\code{dobserv_dep_obs} returns aic table of results
}
\examples{
#
fname=system.file('extdata','sample.csv',package='dobserv')
data=pool_lt10(fname); d1=read.csv(fname,as.is=T)
#   pool CAGO,PUMA even though > 10 detections because all detections were by same obs.
i=which(data$sp=="CAGO" | data$sp=="PUMA"); data$sp[i]='grp1'

#  summarize by species...
sp=as.factor(data$sp); usp=levels(sp); nsp=length(usp); d2=matrix(0,2*nsp,2)
jj=(as.numeric(sp)-1)*2+(data[,1]==data[1,1])+1
for (i in 1:nrow(data)) d2[jj[i],]=d2[jj[i],]+as.numeric(data[i,3:4])
d2=data.frame(obs=rep(1:2,nsp),sp=rep(as.character(usp),each=2),X1=d2[,1],X01=d2[,2])

 #   run some models...
   #    ~obs means detection depends only on observer,
   #    ~sp means detection depends only on species,
   #    ~xxxx means detection depends on input covariate xxxx

z1=dobserv_dep_obs(d2,mods=c(~obs,~-1+sp,~sp+obs,~sp*obs))
#   z1 is a list with output from each of the models above (plus default model, ~1)

#  print results from model, p(sp*obs) (ie., detection different for each
#                                         species and observer)
print(round(z1$m$`p(sp * obs)`$z,4))
}
\seealso{
dobserv_indep_obs
}
\author{
Jim Hines
}
