% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dobserv_funcs.R
\name{dobserv_indep_obs}
\alias{dobserv_indep_obs}
\title{runs double-observer analysis for independent observers}
\usage{
dobserv_indep_obs(dobsdata, mods = c(~obs))
}
\arguments{
\item{mods}{list of model definitions. Model definitions are in GLM form.\cr
 \itemize{
 \item \code{~1} means detection is constant for all observers and species.\cr
 \item \code{~sp} means detection varies by species (constant across observers)\cr
 \item \code{~obs} means detection varies by observer (constant across species)\cr
 \item \code{~sp*obs} means detection varies by species and observer\cr
 \item \code{~xxxx} means detection varies by input covariate, xxxx\cr
}}

\item{dobs_data}{data frame with the following fields:\cr
\itemize{
 \item \code{obs} observer number for primary observer
 \item \code{species} name of species
 \item \code{X10} number of individuals of species detected by observer 1
 and missed by observer 2
 \item \code{X01} number of individuals of species missed by observer 1
 and detected by observer 2
 \item \code{X11} number of individuals of species detected by both observers
 }}
}
\value{
aic table of model results
}
\description{
\code{dobserv_indep_obs} returns aic table of results
}
\examples{
#
\dontrun{

fname=system.file('extdata','sample3.csv',package='dobserv')

 #  read sample data file which includes a covariate (temperature) in the last column
d3=read.csv(fname,header=F,skip=1); colnames(d3)=c('obs','sp','X10','X01','X11','temp')
 #  run a few models...
z2=dobserv_indep_obs(d3,mods=c(~obs,~temp*obs))
 #  print estimates for each species...
print(z2$m$`p(temp * obs)`$z)
 #  print estimate of total number of individuals...
print(z2$m$`p(temp * obs)`$ntotal)
 }
}
\seealso{
dobserv_dep_obs
}
\author{
Jim Hines
}
